==> openshift-model-6.6.1-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySubjectReviewFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSecurityPolicySubjectReviewFluent<A extends PodSecurityPolicySubjectReviewFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSecurityPolicySubjectReviewSpec getSpec();
  public PodSecurityPolicySubjectReviewSpec buildSpec();
  public A withSpec(PodSecurityPolicySubjectReviewSpec spec);
  public Boolean hasSpec();
  public PodSecurityPolicySubjectReviewFluent.SpecNested<A> withNewSpec();
  public PodSecurityPolicySubjectReviewFluent.SpecNested<A> withNewSpecLike(PodSecurityPolicySubjectReviewSpec item);
  public PodSecurityPolicySubjectReviewFluent.SpecNested<A> editSpec();
  public PodSecurityPolicySubjectReviewFluent.SpecNested<A> editOrNewSpec();
  public PodSecurityPolicySubjectReviewFluent.SpecNested<A> editOrNewSpecLike(PodSecurityPolicySubjectReviewSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSecurityPolicySubjectReviewStatus getStatus();
  public PodSecurityPolicySubjectReviewStatus buildStatus();
  public A withStatus(PodSecurityPolicySubjectReviewStatus status);
  public Boolean hasStatus();
  public PodSecurityPolicySubjectReviewFluent.StatusNested<A> withNewStatus();
  public PodSecurityPolicySubjectReviewFluent.StatusNested<A> withNewStatusLike(PodSecurityPolicySubjectReviewStatus item);
  public PodSecurityPolicySubjectReviewFluent.StatusNested<A> editStatus();
  public PodSecurityPolicySubjectReviewFluent.StatusNested<A> editOrNewStatus();
  public PodSecurityPolicySubjectReviewFluent.StatusNested<A> editOrNewStatusLike(PodSecurityPolicySubjectReviewStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface SpecNested<N> extends Nested<N>,PodSecurityPolicySubjectReviewSpecFluent<PodSecurityPolicySubjectReviewFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,PodSecurityPolicySubjectReviewStatusFluent<PodSecurityPolicySubjectReviewFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySubjectReviewFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSecurityPolicySubjectReviewFluent<A extends PodSecurityPolicySubjectReviewFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSecurityPolicySubjectReviewSpec getSpec();
  public PodSecurityPolicySubjectReviewSpec buildSpec();
  public A withSpec(PodSecurityPolicySubjectReviewSpec spec);
  public Boolean hasSpec();
  public PodSecurityPolicySubjectReviewFluent.SpecNested<A> withNewSpec();
  public PodSecurityPolicySubjectReviewFluent.SpecNested<A> withNewSpecLike(PodSecurityPolicySubjectReviewSpec item);
  public PodSecurityPolicySubjectReviewFluent.SpecNested<A> editSpec();
  public PodSecurityPolicySubjectReviewFluent.SpecNested<A> editOrNewSpec();
  public PodSecurityPolicySubjectReviewFluent.SpecNested<A> editOrNewSpecLike(PodSecurityPolicySubjectReviewSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSecurityPolicySubjectReviewStatus getStatus();
  public PodSecurityPolicySubjectReviewStatus buildStatus();
  public A withStatus(PodSecurityPolicySubjectReviewStatus status);
  public Boolean hasStatus();
  public PodSecurityPolicySubjectReviewFluent.StatusNested<A> withNewStatus();
  public PodSecurityPolicySubjectReviewFluent.StatusNested<A> withNewStatusLike(PodSecurityPolicySubjectReviewStatus item);
  public PodSecurityPolicySubjectReviewFluent.StatusNested<A> editStatus();
  public PodSecurityPolicySubjectReviewFluent.StatusNested<A> editOrNewStatus();
  public PodSecurityPolicySubjectReviewFluent.StatusNested<A> editOrNewStatusLike(PodSecurityPolicySubjectReviewStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface SpecNested<N> extends Nested<N>,PodSecurityPolicySubjectReviewSpecFluent<PodSecurityPolicySubjectReviewFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,PodSecurityPolicySubjectReviewStatusFluent<PodSecurityPolicySubjectReviewFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
